@@ -1,10 +1,12 @@
 package CPANPLUS::Dist::Build;
+$CPANPLUS::Dist::Build::VERSION = '0.84';
+#ABSTRACT: CPANPLUS plugin to install packages that use Build.PL
 
 use if $] > 5.017, 'deprecate';
 
 use strict;
 use warnings;
-use vars    qw[@ISA $STATUS $VERSION];
+use vars    qw[@ISA $STATUS];
 @ISA =      qw[CPANPLUS::Dist];
 
 use CPANPLUS::Internals::Constants;
@@ -32,118 +34,7 @@ use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 local $Params::Check::VERBOSE = 1;
 
-$VERSION = '0.82';
 
-=pod
-
-=head1 NAME
-
-CPANPLUS::Dist::Build - CPANPLUS plugin to install packages that use Build.PL
-
-=head1 SYNOPSIS
-
-    my $build = CPANPLUS::Dist->new(
-                                format  => 'CPANPLUS::Dist::Build',
-                                module  => $modobj,
-                            );
-
-    $build->prepare;    # runs Build.PL
-    $build->create;     # runs build && build test
-    $build->install;    # runs build install
-
-
-=head1 DESCRIPTION
-
-C<CPANPLUS::Dist::Build> is a distribution class for C<Module::Build>
-related modules.
-Using this package, you can create, install and uninstall perl
-modules. It inherits from C<CPANPLUS::Dist>.
-
-Normal users won't have to worry about the interface to this module,
-as it functions transparently as a plug-in to C<CPANPLUS> and will
-just C<Do The Right Thing> when it's loaded.
-
-=head1 ACCESSORS
-
-=over 4
-
-=item C<parent()>
-
-Returns the C<CPANPLUS::Module> object that parented this object.
-
-=item C<status()>
-
-Returns the C<Object::Accessor> object that keeps the status for
-this module.
-
-=back
-
-=head1 STATUS ACCESSORS
-
-All accessors can be accessed as follows:
-    $build->status->ACCESSOR
-
-=over 4
-
-=item C<build_pl ()>
-
-Location of the Build file.
-Set to 0 explicitly if something went wrong.
-
-=item C<build ()>
-
-BOOL indicating if the C<Build> command was successful.
-
-=item C<test ()>
-
-BOOL indicating if the C<Build test> command was successful.
-
-=item C<prepared ()>
-
-BOOL indicating if the C<prepare> call exited successfully
-This gets set after C<perl Build.PL>
-
-=item C<distdir ()>
-
-Full path to the directory in which the C<prepare> call took place,
-set after a call to C<prepare>.
-
-=item C<created ()>
-
-BOOL indicating if the C<create> call exited successfully. This gets
-set after C<Build> and C<Build test>.
-
-=item C<installed ()>
-
-BOOL indicating if the module was installed. This gets set after
-C<Build install> exits successfully.
-
-=item uninstalled ()
-
-BOOL indicating if the module was uninstalled properly.
-
-=item C<_create_args ()>
-
-Storage of the arguments passed to C<create> for this object. Used
-for recursive calls when satisfying prerequisites.
-
-=item C<_install_args ()>
-
-Storage of the arguments passed to C<install> for this object. Used
-for recursive calls when satisfying prerequisites.
-
-=back
-
-=cut
-
-=head1 METHODS
-
-=head2 $bool = CPANPLUS::Dist::Build->format_available();
-
-Returns a boolean indicating whether or not you can use this package
-to create and install modules in your environment.
-
-=cut
 
 ### check if the format is available ###
 sub format_available {
@@ -158,14 +49,6 @@ sub format_available {
 }
 
 
-=head2 $bool = $dist->init();
-
-Sets up the C<CPANPLUS::Dist::Build> object for use.
-Effectively creates all the needed status accessors.
-
-Called automatically whenever you create a new C<CPANPLUS::Dist> object.
-
-=cut
 
 sub init {
     my $dist    = shift;
@@ -182,24 +65,6 @@ sub init {
     return 1;
 }
 
-=pod
-
-=head2 $bool = $dist->prepare([perl => '/path/to/perl', buildflags => 'EXTRA=FLAGS', force => BOOL, verbose => BOOL])
-
-C<prepare> prepares a distribution, running C<Build.PL>
-and establishing any prerequisites this
-distribution has.
-
-The variable C<PERL5_CPANPLUS_IS_EXECUTING> will be set to the full path
-of the C<Build.PL> that is being executed. This enables any code inside
-the C<Build.PL> to know that it is being installed via CPANPLUS.
-
-After a successful C<prepare> you may call C<create> to create the
-distribution, followed by C<install> to actually install it.
-
-Returns true on success and false on failure.
-
-=cut
 
 sub prepare {
     ### just in case you already did a create call for this module object
@@ -474,26 +339,6 @@ sub _find_prereqs {
     return { %$href };
 }
 
-=pod
-
-=head2 $dist->create([perl => '/path/to/perl', buildflags => 'EXTRA=FLAGS', prereq_target => TARGET, force => BOOL, verbose => BOOL, skiptest => BOOL])
-
-C<create> preps a distribution for installation. This means it will
-run C<Build> and C<Build test>.
-This will also satisfy any prerequisites the module may have.
-
-If you set C<skiptest> to true, it will skip the C<Build test> stage.
-If you set C<force> to true, it will go over all the stages of the
-C<Build> process again, ignoring any previously cached results. It
-will also ignore a bad return value from C<Build test> and still allow
-the operation to return true.
-
-Returns true on success and false on failure.
-
-You may then call C<< $dist->install >> on the object to actually
-install it.
-
-=cut
 
 sub create {
     ### just in case you already did a create call for this module object
@@ -721,13 +566,6 @@ sub create {
     return $dist->status->created( $fail ? 0 : 1 );
 }
 
-=head2 $dist->install([verbose => BOOL, perl => /path/to/perl])
-
-Actually installs the created dist.
-
-Returns true on success and false on failure.
-
-=cut
 
 sub install {
     ### just in case you already did a create call for this module object
@@ -861,24 +699,6 @@ sub _buildflags_as_list {
     return Module::Build->split_like_shell($flags);
 }
 
-=head1 AUTHOR
-
-Originally by Jos Boumans E<lt>kane@cpan.orgE<gt>.  Brought to working
-condition by Ken Williams E<lt>kwilliams@cpan.orgE<gt>.
-
-Other hackery and currently maintained by Chris C<BinGOs> Williams ( no relation ). E<lt>bingos@cpan.orgE<gt>.
-
-=head1 LICENSE
-
-The CPAN++ interface (of which this module is a part of) is
-copyright (c) 2001, 2002, 2003, 2004, 2005 Jos Boumans E<lt>kane@cpan.orgE<gt>.
-All rights reserved.
-
-This library is free software;
-you may redistribute and/or modify it under the same
-terms as Perl itself.
-
-=cut
 
 qq[Putting the Module::Build into CPANPLUS];
 
@@ -890,3 +710,181 @@ qq[Putting the Module::Build into CPANPLUS];
 # End:
 # vim: expandtab shiftwidth=4:
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+CPANPLUS::Dist::Build - CPANPLUS plugin to install packages that use Build.PL
+
+=head1 VERSION
+
+version 0.84
+
+=head1 SYNOPSIS
+
+    my $build = CPANPLUS::Dist->new(
+                                format  => 'CPANPLUS::Dist::Build',
+                                module  => $modobj,
+                            );
+
+    $build->prepare;    # runs Build.PL
+    $build->create;     # runs build && build test
+    $build->install;    # runs build install
+
+=head1 DESCRIPTION
+
+C<CPANPLUS::Dist::Build> is a distribution class for C<Module::Build>
+related modules.
+Using this package, you can create, install and uninstall perl
+modules. It inherits from C<CPANPLUS::Dist>.
+
+Normal users won't have to worry about the interface to this module,
+as it functions transparently as a plug-in to C<CPANPLUS> and will
+just C<Do The Right Thing> when it's loaded.
+
+=head1 ACCESSORS
+
+=over 4
+
+=item C<parent()>
+
+Returns the C<CPANPLUS::Module> object that parented this object.
+
+=item C<status()>
+
+Returns the C<Object::Accessor> object that keeps the status for
+this module.
+
+=back
+
+=head1 STATUS ACCESSORS
+
+All accessors can be accessed as follows:
+    $build->status->ACCESSOR
+
+=over 4
+
+=item C<build_pl ()>
+
+Location of the Build file.
+Set to 0 explicitly if something went wrong.
+
+=item C<build ()>
+
+BOOL indicating if the C<Build> command was successful.
+
+=item C<test ()>
+
+BOOL indicating if the C<Build test> command was successful.
+
+=item C<prepared ()>
+
+BOOL indicating if the C<prepare> call exited successfully
+This gets set after C<perl Build.PL>
+
+=item C<distdir ()>
+
+Full path to the directory in which the C<prepare> call took place,
+set after a call to C<prepare>.
+
+=item C<created ()>
+
+BOOL indicating if the C<create> call exited successfully. This gets
+set after C<Build> and C<Build test>.
+
+=item C<installed ()>
+
+BOOL indicating if the module was installed. This gets set after
+C<Build install> exits successfully.
+
+=item uninstalled ()
+
+BOOL indicating if the module was uninstalled properly.
+
+=item C<_create_args ()>
+
+Storage of the arguments passed to C<create> for this object. Used
+for recursive calls when satisfying prerequisites.
+
+=item C<_install_args ()>
+
+Storage of the arguments passed to C<install> for this object. Used
+for recursive calls when satisfying prerequisites.
+
+=back
+
+=head1 METHODS
+
+=head2 $bool = CPANPLUS::Dist::Build->format_available();
+
+Returns a boolean indicating whether or not you can use this package
+to create and install modules in your environment.
+
+=head2 $bool = $dist->init();
+
+Sets up the C<CPANPLUS::Dist::Build> object for use.
+Effectively creates all the needed status accessors.
+
+Called automatically whenever you create a new C<CPANPLUS::Dist> object.
+
+=head2 $bool = $dist->prepare([perl => '/path/to/perl', buildflags => 'EXTRA=FLAGS', force => BOOL, verbose => BOOL])
+
+C<prepare> prepares a distribution, running C<Build.PL>
+and establishing any prerequisites this
+distribution has.
+
+The variable C<PERL5_CPANPLUS_IS_EXECUTING> will be set to the full path
+of the C<Build.PL> that is being executed. This enables any code inside
+the C<Build.PL> to know that it is being installed via CPANPLUS.
+
+After a successful C<prepare> you may call C<create> to create the
+distribution, followed by C<install> to actually install it.
+
+Returns true on success and false on failure.
+
+=head2 $dist->create([perl => '/path/to/perl', buildflags => 'EXTRA=FLAGS', prereq_target => TARGET, force => BOOL, verbose => BOOL, skiptest => BOOL])
+
+C<create> preps a distribution for installation. This means it will
+run C<Build> and C<Build test>.
+This will also satisfy any prerequisites the module may have.
+
+If you set C<skiptest> to true, it will skip the C<Build test> stage.
+If you set C<force> to true, it will go over all the stages of the
+C<Build> process again, ignoring any previously cached results. It
+will also ignore a bad return value from C<Build test> and still allow
+the operation to return true.
+
+Returns true on success and false on failure.
+
+You may then call C<< $dist->install >> on the object to actually
+install it.
+
+=head2 $dist->install([verbose => BOOL, perl => /path/to/perl])
+
+Actually installs the created dist.
+
+Returns true on success and false on failure.
+
+=head1 PROMINENCE
+
+Originally by Jos Boumans E<lt>kane@cpan.orgE<gt>.  Brought to working
+condition by Ken Williams E<lt>kwilliams@cpan.orgE<gt>.
+
+Other hackery and currently maintained by Chris C<BinGOs> Williams ( no relation ). E<lt>bingos@cpan.orgE<gt>.
+
+=head1 AUTHOR
+
+Jos Boumans <kane[at]cpan.org>, Ken Williams <kwilliams@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Jos Boumans, Ken Williams, Chris Williams and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
