@@ -1,4 +1,6 @@
 package CPANPLUS::Dist::Build::Constants;
+$CPANPLUS::Dist::Build::Constants::VERSION = '0.84';
+#ABSTRACT: Constants for CPANPLUS::Dist::Build
 
 use if $] > 5.017, 'deprecate';
 
@@ -9,9 +11,8 @@ use File::Spec;
 BEGIN {
 
     require Exporter;
-    use vars    qw[$VERSION @ISA @EXPORT];
+    use vars    qw[@ISA @EXPORT];
 
-    $VERSION    = '0.82';
     @ISA        = qw[Exporter];
     @EXPORT     = qw[ BUILD_DIR BUILD CPDB_PERL_WRAPPER];
 }
@@ -37,10 +38,28 @@ use constant CPDB_PERL_WRAPPER   => 'use strict; BEGIN { my $old = select STDERR
 
 1;
 
+
+# Local variables:
+# c-indentation-style: bsd
+# c-basic-offset: 4
+# indent-tabs-mode: nil
+# End:
+# vim: expandtab shiftwidth=4:
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 CPANPLUS::Dist::Build::Constants - Constants for CPANPLUS::Dist::Build
 
+=head1 VERSION
+
+version 0.84
+
 =head1 SYNOPSIS
 
   use CPANPLUS::Dist::Build::Constants;
@@ -49,26 +68,20 @@ CPANPLUS::Dist::Build::Constants - Constants for CPANPLUS::Dist::Build
 
 CPANPLUS::Dist::Build::Constants provides some constants required by L<CPANPLUS::Dist::Build>.
 
-=head1 AUTHOR
+=head1 PROMINENCE
 
 Originally by Jos Boumans E<lt>kane@cpan.orgE<gt>.  Brought to working
 condition and currently maintained by Ken Williams E<lt>kwilliams@cpan.orgE<gt>.
 
-=head1 LICENSE
+=head1 AUTHOR
 
-The CPAN++ interface (of which this module is a part of) is
-copyright (c) 2001, 2002, 2003, 2004, 2005 Jos Boumans E<lt>kane@cpan.orgE<gt>.
-All rights reserved.
+Jos Boumans <kane[at]cpan.org>, Ken Williams <kwilliams@cpan.org>
 
-This library is free software;
-you may redistribute and/or modify it under the same
-terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Jos Boumans, Ken Williams, Chris Williams and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-# Local variables:
-# c-indentation-style: bsd
-# c-basic-offset: 4
-# indent-tabs-mode: nil
-# End:
-# vim: expandtab shiftwidth=4:
